append

Function append 

pub fn append<P>(path: P, content: &str) -> Result<(), Error>
where P: AsRef<Path>,
Append the content to the file

  • if the file is exists, append the content to the file
  • if the file is not exists, create the file and write the content to the file