FsError

Enum FsError 

pub enum FsError {
    FileNotFound(PathBuf),
    DirNotFound(PathBuf),
    Create {
        path: PathBuf,
        reason: String,
    },
    Read {
        path: PathBuf,
        reason: String,
    },
    Write {
        path: PathBuf,
        reason: String,
    },
    Delete {
        path: PathBuf,
        reason: String,
    },
    UnExpected(String),
}
File System Error

Variants



FileNotFound(PathBuf)

File Not Found



DirNotFound(PathBuf)

Dir Not Found



Create

Create Error (dir or file)

Fields

path: PathBuf
reason: String


Read

Read Error

Fields

path: PathBuf
reason: String


Write

Write Error

Fields

path: PathBuf
reason: String


Delete

Delete Error

Fields

path: PathBuf
reason: String


UnExpected(String)

UnExpected Error, maybe the file or dir can not access to be read or wrote or found