pub struct ParseError {
pub target: String,
pub other: Option<String>,
pub ty: ParseType,
}Expand description
Parse Error
common error for parse, if any you need to parse, but failed, you can use this error
Fields
target: Stringother: Option<String>ty: ParseTypeImplementations
Sourceimpl ParseError
impl ParseError
pub fn new(target: &str, ty: ParseType) -> Self
pub fn rust_dep(target: &str) -> Self
pub fn set_other(&mut self, other: &str) -> &mut Self
pub fn set_ty(&mut self, ty: ParseType) -> &mut Self
pub fn template(target: &str) -> Self
pub fn other(target: &str, ty: &str) -> Self