append
gen_
utils
0.1.2
append
Sections
Append the content to the file
In gen_
utils::
common::
fs
gen_utils
::
common
::
fs
Function
append
pub fn append<P>(path: P, content: &
str
) ->
Result
<
()
,
Error
>
where P:
AsRef
<
Path
>,

Append the content to the file
if the file is exists, append the content to the file
if the file is not exists, create the file and write the content to the file