pub trait Builder: Any {
type From;
type To;
// Required methods
fn new(value: Self::From) -> Self;
fn build(self) -> Self::To;
}Expand description
Builder trait
Builder trait is a trait to builder pattern
Although there are few methods that need to be implemented uniformly in this trait, it exists as a specification
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.