pub enum FsError {
FileNotFound(PathBuf),
DirNotFound(PathBuf),
Create {
path: PathBuf,
reason: String,
},
Read {
path: PathBuf,
reason: String,
},
Write {
path: PathBuf,
reason: String,
},
Delete {
path: PathBuf,
reason: String,
},
UnExpected(String),
}Expand description
File System Error
Variants
FileNotFound(PathBuf)
File Not Found
DirNotFound(PathBuf)
Dir Not Found
Create
Create Error (dir or file)
Read
Read Error
Write
Write Error
Delete
Delete Error
UnExpected(String)
UnExpected Error, maybe the file or dir can not access to be read or wrote or found